@@ -2,7 +2,7 @@
 
 /**************************************************************************************************
 Platform
- 
+
 One of the following platforms should be defined (either in code or as a project setting):
 PLATFORM_WINDOWS
 PLATFORM_APPLE
@@ -24,6 +24,13 @@ PLATFORM_LINUX
 #undef __forceinline
 #endif
 
+/**************************************************************************************************
+64-bit
+**************************************************************************************************/
+#if defined(_WIN64) || defined(__x86_64__)
+#define APE_64_BIT
+#endif
+
 /**************************************************************************************************
 Warnings
 **************************************************************************************************/
@@ -39,20 +46,24 @@ Global includes
 #include <math.h>
 
 #if defined(PLATFORM_WINDOWS)
-    #define NOMINMAX // remove the global min / max macros so ape_min / ape_max will always be used
+    #ifndef NOMINMAX
+        #define NOMINMAX // remove the global min / max macros so ape_min / ape_max will always be used
+    #endif
     #include "WindowsEnvironment.h"
     #define WIN32_LEAN_AND_MEAN
+    #ifdef _MSC_VER
+        #pragma warning(push) // push and pop warnings because the windows includes suppresses some like 4514
+    #endif
     #include <windows.h>
+    #ifdef _MSC_VER
+        #pragma warning(pop)
+    #endif
     #include <tchar.h>
     #include <assert.h>
 #else
-    #ifndef _MSC_VER
-        #include <unistd.h>
-    #endif
+    #include <unistd.h>
     #include <time.h>
-    #ifndef _MSC_VER
-        #include <sys/time.h>
-    #endif
+    #include <sys/time.h>
     #include <sys/types.h>
     #include <sys/stat.h>
     #include <wchar.h>
@@ -60,7 +71,7 @@ Global includes
 #endif
 #define ape_max(a,b)    (((a) > (b)) ? (a) : (b))
 #define ape_min(a,b)    (((a) < (b)) ? (a) : (b))
-#define CLEAR(destination) memset(&destination, 0, sizeof (destination))
+#define APE_CLEAR(destination) memset(&destination, 0, sizeof (destination))
 
 /**************************************************************************************************
 Packing
@@ -87,8 +98,8 @@ Version
 // build the version string
 #define STRINGIZE2(s) #s
 #define STRINGIZE(s) STRINGIZE2(s)
-#define MAC_VER_FILE_VERSION_STR               STRINGIZE(MAC_VERSION_MAJOR) _T(".") STRINGIZE(MAC_VERSION_REVISION) 
-#define MAC_VER_FILE_VERSION_STR_NARROW        STRINGIZE(MAC_VERSION_MAJOR) "." STRINGIZE(MAC_VERSION_REVISION) 
+#define MAC_VER_FILE_VERSION_STR                        STRINGIZE(MAC_VERSION_MAJOR) _T(".") STRINGIZE(MAC_VERSION_REVISION)
+#define MAC_VER_FILE_VERSION_STR_NARROW                 STRINGIZE(MAC_VERSION_MAJOR) "." STRINGIZE(MAC_VERSION_REVISION)
 
 #define MAC_FILE_VERSION_NUMBER                         3990
 #define MAC_VERSION_STRING                              MAC_VER_FILE_VERSION_STR
@@ -139,9 +150,6 @@ Global compiler settings (useful for porting)
 #define ENABLE_COMPRESSION_MODE_HIGH
 #define ENABLE_COMPRESSION_MODE_EXTRA_HIGH
 
-// switch to legacy encoding (for support in FFMpeg, etc.)
-//#define LEGACY_ENCODE
-
 /**************************************************************************************************
 Global types
 **************************************************************************************************/
@@ -152,7 +160,7 @@ namespace APE
     typedef uint32_t                                    uint32;
     typedef uint16_t                                    uint16;
     typedef uint8_t                                     uint8;
-    
+
     typedef int64_t                                     int64;
     typedef int32_t                                     int32;
     typedef int16_t                                     int16;
@@ -179,7 +187,7 @@ Global macros
 
 #define APE_TRUNCATE ((size_t)-1)
 
-#define POINTER_TO_INT64(POINTER) (int64)(uintptr_t)POINTER
+#define POINTER_TO_INT64(POINTER) static_cast<int64>(reinterpret_cast<uintptr_t>(POINTER))
 
 #if defined(PLATFORM_WINDOWS)
     #define IO_USE_WIN_FILE_IO
@@ -196,7 +204,7 @@ Global macros
         #if defined(_DEBUG)
             #define ASSERT(e)                            assert(e)
         #else
-            #define ASSERT(e)                            
+            #define ASSERT(e)
         #endif
     #endif
 #else
@@ -213,7 +221,11 @@ Global macros
     #undef  ASSERT
     #define ASSERT(e)
     #define wcsncpy_s(A, B, C, D) wcsncpy(A, C, D)
-    #define wcscpy_s(A, B, C) wcscpy(A, C)
+    inline wchar_t * wcscpy_s(wchar_t * dest, size_t destsz, const wchar_t * src)
+    {
+        (void) destsz; // this avoids an unreferenced variable
+        return wcscpy(dest, src);
+    }
     #define wcscat_s(A, B, C) wcscat(A, C)
     #define sprintf_s(A, B, C, D) sprintf(A, C, D)
     #define strcpy_s(A, B, C) strcpy(A, C)
@@ -226,17 +238,17 @@ WAVE format descriptor (binary compatible with Windows define, but in the APE na
 namespace APE
 {
     #pragma pack(push, 1)
-    typedef struct tWAVEFORMATEX
+    struct WAVEFORMATEX
     {
-        WORD        wFormatTag{0};         /* format type */
-        WORD        nChannels{0};          /* number of channels (i.e. mono, stereo...) */
-        uint32      nSamplesPerSec{0};     /* sample rate */
-        uint32      nAvgBytesPerSec{0};    /* for buffer estimation */
-        WORD        nBlockAlign{0};        /* block size of data */
-        WORD        wBitsPerSample{0};     /* number of bits per sample of mono data */
-        WORD        cbSize{0};             /* the count in bytes of the size of */
+        WORD        wFormatTag;         /* format type */
+        WORD        nChannels;          /* number of channels (i.e. mono, stereo...) */
+        uint32      nSamplesPerSec;     /* sample rate */
+        uint32      nAvgBytesPerSec;    /* for buffer estimation */
+        WORD        nBlockAlign;        /* block size of data */
+        WORD        wBitsPerSample;     /* number of bits per sample of mono data */
+        WORD        cbSize;             /* the count in bytes of the size of */
         /* extra information (after cbSize) */
-    } WAVEFORMATEX;
+    };
     #pragma pack(pop)
 }
 
@@ -266,9 +278,9 @@ Global defines
 #else
     #define APE_FILENAME_SLASH '/'
 #endif
-#define BYTES_IN_KILOBYTE            1024
-#define BYTES_IN_MEGABYTE            (1024 * BYTES_IN_KILOBYTE)
-#define BYTES_IN_GIGABYTE            int64(1024 * BYTES_IN_MEGABYTE)
+#define APE_BYTES_IN_KILOBYTE            1024
+#define APE_BYTES_IN_MEGABYTE            1048576
+#define APE_BYTES_IN_GIGABYTE            int64(1073741824)
 
 /**************************************************************************************************
 Byte order
@@ -283,13 +295,6 @@ Channels
 #define APE_MINIMUM_CHANNELS 1
 #define APE_MAXIMUM_CHANNELS 32
 
-/**************************************************************************************************
-64-bit
-**************************************************************************************************/
-#if defined(_WIN64) || defined(__x86_64__)
-#define APE_64_BIT
-#endif
-
 /**************************************************************************************************
 Macros
 **************************************************************************************************/
@@ -301,7 +306,7 @@ Macros
 #define SAFE_VOID_CLASS_DELETE(POINTER, Class) { Class *pClass = (Class *) POINTER; if (pClass) { delete pClass; POINTER = NULL; } }
 #define SAFE_FILE_CLOSE(HANDLE) if (HANDLE != INVALID_HANDLE_VALUE) { CloseHandle(HANDLE); HANDLE = INVALID_HANDLE_VALUE; }
 
-#define ODN(NUMBER) { TCHAR cNumber[16]; _stprintf(cNumber, _T("%d\n"), int(NUMBER)); ODS(cNumber); }
+#define ODN(NUMBER) { TCHAR cNumber[16]; _stprintf(cNumber, _T("%d\n"), static_cast<int>(NUMBER)); ODS(cNumber); }
 
 #define CATCH_ERRORS(CODE) try { CODE } catch(...) { }
 
@@ -309,7 +314,7 @@ Macros
 #define RETURN_VALUE_ON_ERROR(FUNCTION, VALUE) { int nFunctionResult = FUNCTION; if (nFunctionResult != 0) { return VALUE; } }
 #define RETURN_ON_EXCEPTION(CODE, VALUE) { try { CODE } catch(...) { return VALUE; } }
 
-#define THROW_ON_ERROR(CODE) { intn nThrowResult = (intn) CODE; if (nThrowResult != 0) throw(nThrowResult); }
+#define THROW_ON_ERROR(CODE) { intn nThrowResult = static_cast<intn> (CODE); if (nThrowResult != 0) throw(nThrowResult); }
 
 #define EXPAND_8_TIMES(CODE) CODE CODE CODE CODE CODE CODE CODE CODE
 #define EXPAND_9_TIMES(CODE) CODE CODE CODE CODE CODE CODE CODE CODE CODE
