@@ -1,22 +1,17 @@
 #pragma once
 
-#ifdef WINAMP_VERSION
-!define VERSION "7.56"
-!define ALT_VER "7_56"
-#endif
-
 /* build batch file */
 /*
 #ifdef APE_BATCH_FILE_VERSION
-Set _MA=756
-Set _MAV=7.56
+Set _MA=881
+Set _MAV=8.81
 #endif
 */
 
 /* major version number */
-#define MAC_VERSION_MAJOR 7
+#define MAC_VERSION_MAJOR 8
 
 /* build version number */
-#define MAC_VERSION_REVISION 56
+#define MAC_VERSION_REVISION 81
 
 /* leave this so the end of file doesn't get truncated */
